@@ -1,6 +1,7 @@
 from django.conf.urls import url
 
 from .views import SelfServiceBookingView, SelfServiceIndexView, SettingsView
+from . import api
 
 urlpatterns = [
     url(
@@ -8,6 +9,9 @@ urlpatterns = [
         SettingsView.as_view(),
         name="settings",
     ),
+    url(r'^api/v1/organizers/(?P<organizer>[^/]+)/events/(?P<event>[^/]+)/items/(?P<item>[^/]+)/vacc_autosched/$',
+        api.ItemView.as_view(),
+        name="api.item"),
 ]
 
 event_patterns = [
